@@ -20,18 +20,27 @@ public:
     QLineEdit *stringa3LineEdit;
     QLineEdit *stringa4LineEdit;
     QLineEdit *stringa5LineEdit;
+    QLineEdit *stringa6LineEdit;
+    QLineEdit *stringa7LineEdit;
+    QLineEdit *stringa8LineEdit;
 
     QCheckBox *stringa1CheckBox;
     QCheckBox *stringa2CheckBox;
     QCheckBox *stringa3CheckBox;
     QCheckBox *stringa4CheckBox;
     QCheckBox *stringa5CheckBox;
+    QCheckBox *stringa6CheckBox;
+    QCheckBox *stringa7CheckBox;
+    QCheckBox *stringa8CheckBox;
 
     QCheckBox *dataCheckBox;
     QComboBox *dayBox;
     QComboBox *monthBox;
     QComboBox *yearBox;
 
+    QCheckBox *dataRCheckBox;
+    QComboBox *dataRComboBox;
+
     QPushButton *deleteButton;
     QPushButton *infoButton;
     QCheckBox *backgroundCheckBox;
