@@ -7,9 +7,6 @@
 #include <QMessageBox>
 #include <QScrollArea>
 
-
-
-
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent)
 {
@@ -22,17 +19,10 @@ MainWindow::MainWindow(QWidget *parent)
 
     setCentralWidget(scrollArea);
 
-
-
-    //setCentralWidget(w);
-
-
     createActions();
     createMenus();
 	
-	setWindowTitle("AutoRemoveSms");
-
-
+    setWindowTitle("AutoRemoveSms");
 }
 
 MainWindow::~MainWindow()
@@ -42,21 +32,12 @@ MainWindow::~MainWindow()
 
 void MainWindow::createActions()
 {
-
     aboutAction = new QAction(tr("&About"), this);
-    //aboutAction->setIcon(QIcon("/usr/share/icons/hicolor/32x32/hildon/general_help.png"));
     aboutQtAction = new QAction("About QT", this);
     connect(aboutAction, SIGNAL(triggered()), this, SLOT(about()));
     connect(aboutQtAction, SIGNAL(triggered()), this, SLOT(aboutQt()));
-
-
-
-
-
-
 }
 
-
 void MainWindow::createMenus()
 {
     QMenu *menu;
@@ -65,14 +46,10 @@ void MainWindow::createMenus()
     menu->addAction(aboutQtAction);
 }
 
-
-
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About AutoRemoveSms"),
-                tr("<h2>AutoRemoveSms 0.3.2</h2>"
-                   "<p>"
-                   "<p>AutoRemoveSms is an application that allow you to delete your sms by Text, Sender or Received Date. It can be scheduled with Alarmed to auto remove your messages with planned events."
+                tr("<h2>AutoRemoveSms 0.4.1</h2>"
                    "<p>"
                    "<p>Written by GGiovanni (ggiovanni88@yahoo.it)"));
 
@@ -81,8 +58,4 @@ void MainWindow::about()
 void MainWindow::aboutQt()
 {
     QApplication::aboutQt();
-
 }
-
-
-
